==> qmmp_1.1.10.orig.tar.bz2: qmmp-1.1.10/src/plugins/Output/qtmultimedia/translations/qtmultimedia_plugin_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt_BR">
<context>
    <name>OutputQtMultimediaFactory</name>
    <message>
        <location filename="../outputqtmultimediafactory.cpp" line="33"/>
        <source>Qt Multimedia Plugin</source>
        <translation>Plugin Qt Multimedia</translation>
    </message>
    <message>
        <location filename="../outputqtmultimediafactory.cpp" line="58"/>
        <source>About Qt Multimedia Output Plugin</source>
        <translation>Sobre o plugin Qt Multimedia</translation>
    </message>
    <message>
        <location filename="../outputqtmultimediafactory.cpp" line="59"/>
        <source>Qmmp Qt Multimedia Output Plugin</source>
        <translation>Plugin Qmmp Qt Multimedia</translation>
    </message>
    <message>
        <location filename="../outputqtmultimediafactory.cpp" line="60"/>
        <source>Written by: Ivan Ponomarev &lt;ivantrue@gmail.com&gt;</source>
        <translation>Desenvolvido por: Ivan Ponomarev &lt;ivantrue@gmail.com&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Qt Multimedia Plugin Settings</source>
        <translation>Preferências do plugin Qt Multimedia</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="46"/>
        <source>Device:</source>
        <translation>Dispositivo:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="36"/>
        <source>Default</source>
        <translation>Padrão</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.6.orig.tar.bz2: qmmp-1.2.6/src/plugins/Output/qtmultimedia/translations/qtmultimedia_plugin_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt_BR">
<context>
    <name>OutputQtMultimediaFactory</name>
    <message>
        <location filename="../outputqtmultimediafactory.cpp" line="33"/>
        <source>Qt Multimedia Plugin</source>
        <translation>Plugin Qt Multimedia</translation>
    </message>
    <message>
        <location filename="../outputqtmultimediafactory.cpp" line="58"/>
        <source>About Qt Multimedia Output Plugin</source>
        <translation>Sobre o plugin Qt Multimedia</translation>
    </message>
    <message>
        <location filename="../outputqtmultimediafactory.cpp" line="59"/>
        <source>Qmmp Qt Multimedia Output Plugin</source>
        <translation>Plugin Qmmp Qt Multimedia</translation>
    </message>
    <message>
        <location filename="../outputqtmultimediafactory.cpp" line="60"/>
        <source>Written by: Ivan Ponomarev &lt;ivantrue@gmail.com&gt;</source>
        <translation>Desenvolvido por: Ivan Ponomarev &lt;ivantrue@gmail.com&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Qt Multimedia Plugin Settings</source>
        <translation>Preferências do plugin Qt Multimedia</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="46"/>
        <source>Device:</source>
        <translation>Dispositivo:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="36"/>
        <source>Default</source>
        <translation>Pré-definido</translation>
    </message>
</context>
</TS>
